@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
 from DateTime import DateTime
+from kitconcept import api
 from kitconcept.contentcreator.creator import content_creator_from_folder
 from kitconcept.contentcreator.creator import create_item_runner
 from kitconcept.contentcreator.creator import load_json
 from kitconcept.contentcreator.creator import refresh_objects_created_by_structure
-from kitconcept.contentcreator.testing import (
-    CONTENTCREATOR_CORE_INTEGRATION_TESTING,
-)  # noqa
-from plone import api
+from kitconcept.contentcreator.testing import CONTENTCREATOR_CORE_INTEGRATION_TESTING
 from plone.app.testing import applyProfile
 
 import json
